Simple Wedding Dresses: Best Off-the-Rack Wedding Dresses, Wedding Gowns: Glamour.com
Author: Glamour Magazine
Description: A ton of brides are going for the pretty pretty princess vibe on their wedding day, so lots of wedding dress designers automatically reach for the tulle and the crinolines. {&#8220;Fluffier! Puffier! MORE! } If you&#8217;re a bride who isn&#8217;t feeling the cupcake vibe, I suggest checking out white evening dresses, which tend to be a lot more streamlined. And bonus: Evening gowns are generally less expensive than wedding gowns. (Four of the dresses below are under $1,000.) Here are six off-the-rack I like: !function(d,s,id){var e, p = /^http:/.test(d.location) ? 'http' : 'https';if(!d.getElementById(id)) {e = d.createElement(s);e.id = id;e.src = p + '://' + 'widgets.rewardstyle.com' + '/js/boutique.js';d.body.appendChild(e);}if(typeof window.__boutique === 'object') if(d.readyState === 'complete') {window.__boutique.init();}}(document, 'script', 'boutique-script');JavaScript is currently disabled in this browser. Reactivate it to view this content. Off-the-rack wedding dresses: Yes  [cell cut: 1096 characters, first 1000 kept]

Subscribe | Give a gift | Renew
Log in / Register Promos Hi Promos

- Logout
- Edit Profile

SUBSCRIBE

For Just $1.25 An Issue

SUBSCRIBE
Subscribe
Save the Date

- #### prev story

  5 New Ideas for Wedding Guest Favors

- #### next story

  15 Celebrity Weddings We Can Look Forward to in 2015—and 1 That Might Not Happen

# 6 Wedding Dresses With Zero Fluff, for Brides Who Don’t Want to Look Like a Damn Cupcake

By Kim Fusaro
December 17, 2014

A ton of brides are going for the pretty pretty princess vibe on their wedding day, so lots of wedding dress designers automatically reach for the tulle and the crinolines. {“Fluffier! Puffier! MORE! } If you’re a bride who isn’t feeling the cupcake vibe, I suggest checking out white evening dresses, which tend to be a lot more streamlined. And bonus: Evening gowns are generally less expensive than wedding gowns. (Four of the dresses below are under $1,000.) Here are six off-the-rack I like:

Off-the-rack wedding dresses: Yes or no? Would you want to wear an evening gown on your wedding day? Or does it HAVE to be bridal?

###### Photos: Courtesy of the vendors.

ADVERTISEMENT
Kim Fusaro Weddings and lifestyle writer. Owner of two bad knees and one 1920s fixer-upper. Hoarder of Cherry ChapStick, high-end vacuums, and stray animals. Eats chocolate every day.
FOLLOW ME EMAIL ME

#### Keywords:

- wedding dresses
- wedding gowns

## Recommended

## More Stories Like This

weddings The Essential Guide to Engagement Ring Shopping
By Eliza Krpoyan
November 17, 2014
weddings 18 Perfect Wedding Dresses for Beach Brides
By Kim Fusaro
November 13, 2014

## TRENDING

Princess Mary Had the Dreamiest New Year's Outfit, Ever
Is This the Most Sexist Relationship Advice Ever?
Huh? The Bra You're Supposed to Wear at Night (I Tried It!)